/*
   HtURLCodec.java -- Specialized HtWordCodec which just caters to the
   needs of "url_part_aliases" and "common_url_parts".
   Used for coding URLs when they are on disk; the key and the
   href field in db.docdb.

   $Id: HtURLCodec.java,v 1.1 1999/05/24 19:41:57 eg Exp $

   Copyright (c) 1995-1999 The ht://Dig Group
   Copyright (C) 1999, Edwin Glaser

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
*/

package htsearch;

/**
 * HtURLCodec -- Specialized HtWordCodec which just caters to the
 * needs of "url_part_aliases" and "common_url_parts".
 * Used for coding URLs when they are on disk; the key and the
 * href field in db.docdb.
 */

public class HtURLCodec 
{
  static HtURLCodec _instance;
  final static int FIRST_INTERNAL_SINGLECHAR = 7;
  final static int LAST_INTERNAL_SINGLECHAR = 31;

  String[] frequent;

  HtURLCodec()
  {
	frequent = new String[LAST_INTERNAL_SINGLECHAR +1];
	frequent[7] = "http://";
	frequent[8] = "http://www.";
	frequent[9] = "ftp://";
	frequent[10] = "ftp://ftp.";
	frequent[11] = "/pub/";
	frequent[12] = ".html";
	frequent[13] = ".htm";
	frequent[14] = ".gif";
	frequent[15] = ".jpg";
	frequent[16] = ".jpeg";
	frequent[17] = "/index.html";
	frequent[18] = "/index.htm";
	frequent[19] = ".com/";
	frequent[20] = ".com";
	frequent[21] = "mailto:";
  }

  StringBuffer res = new StringBuffer();

  public synchronized String decode(String orig)
  {
	res.setLength(0);
	for ( int i = 0; i < orig.length(); i++ )
	{
		char c = orig.charAt(i);
		if ( c <= LAST_INTERNAL_SINGLECHAR && frequent[c] != null )
		{
			res.append(frequent[c]);
		}
		else
		{
			res.append(c);
		}
	}

	return res.toString();
  }

  static public HtURLCodec instance()
  {
	if ( _instance == null )
	{
		_instance = new HtURLCodec();
	}
	return _instance;
  }

} // HtURLCodec
